#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>

#include <gnome.h>

#include "menu.h"
#include "callbacks.h"
#include "interface.h"
#include "support.h"

static GnomeUIInfo file_menu_uiinfo[] =
{
  GNOMEUIINFO_MENU_NEW_ITEM (N_("_Nuovo"), N_("Crea una nuova rubrica"), 
			     on_nuovo_file_activate, NULL),
  GNOMEUIINFO_MENU_OPEN_ITEM (on_apri_activate, NULL),
  GNOMEUIINFO_MENU_SAVE_ITEM (on_salva_activate, NULL),
  GNOMEUIINFO_MENU_SAVE_AS_ITEM (on_salva_con_nome_activate, NULL),
  GNOMEUIINFO_SEPARATOR,
  GNOMEUIINFO_MENU_EXIT_ITEM (on_esci_activate, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo modifica_menu_uiinfo[] =
{
  GNOMEUIINFO_MENU_CUT_ITEM (on_taglia_activate, NULL),
  GNOMEUIINFO_MENU_COPY_ITEM (on_copia_activate, NULL),
  GNOMEUIINFO_MENU_PASTE_ITEM (on_incolla_activate, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo ordinamento_uiinfo[] =
{
  {
    GNOME_APP_UI_ITEM, N_("_Crescente"),
    N_("Ordina dal pi piccolo al piu grande"),
    on_crescente_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    0, 0, NULL
  },
  {
    GNOME_APP_UI_ITEM, N_("D_ecrescente"),
    N_("Ordina dal pi grande al pi piccolo"),
    on_decrescente_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    0, 0, NULL
  },
  GNOMEUIINFO_END
};

static GnomeUIInfo vista_menu_uiinfo[] =
{
  {
    GNOME_APP_UI_ITEM, N_("_Alfabetica"),
    N_("Visualizza le schede in ordine alfabetico"),
    on_alfabetica_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    0, 0, NULL
  },
  {
    GNOME_APP_UI_ITEM, N_("_Data ultima modifica"),
    N_("Ordina le schede secondo la data di modifica"),
    on_dimensione_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    0, 0, NULL
  },
  {
    GNOME_APP_UI_ITEM, N_("_Personale"),
    N_("Imposta i criteri di ordinamento"),
    on_personale_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    0, 0, NULL
  },
  GNOMEUIINFO_SEPARATOR,
  {
    GNOME_APP_UI_RADIOITEMS, NULL, NULL, ordinamento_uiinfo,
    NULL, NULL, 0, NULL, 0, 0, NULL
  },
  GNOMEUIINFO_END
};

static GnomeUIInfo opzioni_menu_uiinfo[] =
{
  GNOMEUIINFO_MENU_PREFERENCES_ITEM (on_preferenze_activate, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo aiuto_menu_uiinfo[] =
{
  GNOMEUIINFO_MENU_ABOUT_ITEM (on_about_activate, NULL),
  {
    GNOME_APP_UI_ITEM, N_("La _Calabria"),
    N_("Visitate la Calabria"),
    on_calabria_activate, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
    0, 0, NULL
  },
  {
    GNOME_APP_UI_ITEM, N_("_Dedicato a..."),
    N_("Quseto programma  dedivato a..."),
    on_dedicato_a_activate, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
    0, 0, NULL
  },
  GNOMEUIINFO_END
};

static GnomeUIInfo menubar_uiinfo[] =
{
  GNOMEUIINFO_MENU_FILE_TREE (file_menu_uiinfo),
  GNOMEUIINFO_MENU_EDIT_TREE (modifica_menu_uiinfo),
  GNOMEUIINFO_MENU_VIEW_TREE (vista_menu_uiinfo),
  GNOMEUIINFO_MENU_SETTINGS_TREE (opzioni_menu_uiinfo),
  GNOMEUIINFO_MENU_HELP_TREE (aiuto_menu_uiinfo),
  GNOMEUIINFO_END
};


/*
  Definizione della Toolbar
*/

static GnomeUIInfo toolbar[] = {
  GNOMEUIINFO_ITEM_STOCK(N_("Nuovo"), N_("Crea una nuova rubrica"),
			 on_nuovo_file_activate, GNOME_STOCK_PIXMAP_NEW),
  GNOMEUIINFO_ITEM_STOCK(N_("Apri"), N_("Apri una rubrica esistente"),
			 on_apri_activate, GNOME_STOCK_PIXMAP_OPEN),
  GNOMEUIINFO_ITEM_STOCK(N_("Salva"), N_("Salva la rubrica corrente"),
			 on_salva_activate, GNOME_STOCK_PIXMAP_SAVE),
  GNOMEUIINFO_SEPARATOR,

  GNOMEUIINFO_ITEM_STOCK(N_("Aggiungi"), 
			 N_("Aggiungi una nuova scheda alla rubrica"),
			 aggiungi_scheda_activate, GNOME_STOCK_PIXMAP_ADD),
  GNOMEUIINFO_ITEM_STOCK(N_("Elimina"), 
			 N_("Elimina la scheda selezionata dalla rubrica"),
			 elimina_scheda_activate, GNOME_STOCK_PIXMAP_REMOVE),
  GNOMEUIINFO_ITEM_STOCK(N_("Modifica"), 
			 N_("Modifica la scheda selezionata"),
			 modifica_scheda_activate, GNOME_STOCK_PIXMAP_CONVERT),
  GNOMEUIINFO_SEPARATOR,

  GNOMEUIINFO_ITEM_STOCK(N_("Inizio"), 
			 N_("Mostra la prima scheda della rubrica"),
			 prima_scheda_activate, GNOME_STOCK_PIXMAP_TOP),
  
  GNOMEUIINFO_ITEM_STOCK(N_("Fine"), 
			 N_("Mostra l'ultima scheda della rubrica"),
			 ultima_scheda_activate, GNOME_STOCK_PIXMAP_BOTTON),

  GNOMEUIINFO_ITEM_STOCK(N_("Trova"), 
			 N_("Trova una scheda nella rubrica"),
			 trova_scheda_activate, GNOME_STOCK_PIXMAP_SEARCH),
  GNOMEUIINFO_SEPARATOR,

  GNOMEUIINFO_ITEM_STOCK(N_("Esci"), N_("Esci dal programma"), 
			    chiudi_applicazione, GNOME_STOCK_PIXMAP_EXIT),
  GNOMEUIINFO_END
};


void installa_menu_e_toolbar(GtkWidget *app)
{
GtkWidget *statusbar;
  
  /* creo il menu, la toolbar e la statusbar */
  gnome_app_create_menus(GNOME_APP(app), menubar);
  gnome_app_create_toolbar(GNOME_APP(app), toolbar);
  statusbar = gnome_appbar_new(TRUE, TRUE, GNOME_PREFERENCES_USER);
  
  /* collego la statusbar all'applicazione */
  gnome_app_set_statusbar(GNOME_APP(app),statusbar);
  
  /* collego la statusbar con gli hints "suggerimenti" del menu */
  gnome_app_install_menu_hints(GNOME_APP(app), menubar); 
}


