/*
  modulo rubrica, derivato da gnome-propertybox
*/

/*
  #include <gtk/gtk.h>
  #include <libgnome/gnome-util.h>
  #include <libgnome/gnome-i18n.h>
  #include <libgnomeui/gnome-stock.h>
  #include <libgnome/gnome-config.h>  
  #include <libgnomeui/gnome-preferences.h>
*/

#include <gnome.h>
#include "modulo-rubrica.h"
#include "modulo-interfaccia.h"


enum {
  APPLY,
  HELP,
  LAST_SIGNAL
};


typedef void (*ModuloRubricaSignal) (GtkObject *object, 
				     gint arg,
				     gpointer data);

static void modulo_rubrica_class_init     (ModuloRubricaClass *klass);
static void modulo_rubrica_init           (ModuloRubrica *modulo);
static void modulo_rubrica_marshal_signal (GtkObject *object, 
					   GtkSignalFunc func, 
					   gpointer func_data, 
					   GtkArg *args);
static void modulo_rubrica_destroy        (GtkObject *object);

/* funzioni richiamate da dialog_clicked_cb()
   dipendono dal bottone cliccato
*/
static void applica          (ModuloRubrica *modulo);
static void aiuto            (ModuloRubrica *modulo);
static void applica_e_chiudi (ModuloRubrica *modulo);
static void chiudi           (ModuloRubrica *modulo);

static void dialog_clicked_cb(GnomeDialog *dialog, gint bottone, gpointer data);



/* classe genitore */
static GnomeDialogClass *parent_class = NULL;

static gint modulo_rubrica_signals[LAST_SIGNAL] = { 0 };

/* 
   modulo_rubrica_get_type
   
   ritorna il GtkType del widget ModuloRubrica
*/
GtkType 
modulo_rubrica_get_type(void)
{
  static guint modulo_rubrica_type = 0;
  
  if (!modulo_rubrica_type)
    {
      static const GtkTypeInfo modulo_rubrica_info =
      {
	"ModuloRubrica",
	sizeof(ModuloRubrica),
	sizeof(ModuloRubricaClass),
	(GtkClassInitFunc)  modulo_rubrica_class_init,
	(GtkObjectInitFunc) modulo_rubrica_init,
	NULL, /* riservato per compatibilit */
	NULL, /* riservato per compatibilit */
      };

      modulo_rubrica_type = gtk_type_unique(gnome_dialog_get_type(), 
					    &modulo_rubrica_info);
    }

  return modulo_rubrica_type;
};



static void
modulo_rubrica_class_init(ModuloRubricaClass *klass)
{
  GtkObjectClass *object_class;
  GtkWidgetClass *widget_class;
  GtkWindowClass *window_class;

  object_class = (GtkObjectClass*) klass;
  widget_class = (GtkWidgetClass*) klass;
  window_class = (GtkWindowClass*) klass;

  object_class->destroy = modulo_rubrica_destroy;
 
  parent_class = gtk_type_class(gnome_dialog_get_type());

  modulo_rubrica_signals[APPLY] =
    gtk_signal_new ("apply", 
		    GTK_RUN_LAST,
		    object_class->type,
		    GTK_SIGNAL_OFFSET(ModuloRubricaClass, applica),
		    modulo_rubrica_marshal_signal,
		    GTK_TYPE_NONE, 1, GTK_TYPE_INT);

 modulo_rubrica_signals[HELP] =
    gtk_signal_new ("help", 
		    GTK_RUN_LAST,
		    object_class->type,
		    GTK_SIGNAL_OFFSET(ModuloRubricaClass, aiuto),
		    modulo_rubrica_marshal_signal,
		    GTK_TYPE_NONE, 1, GTK_TYPE_INT);
 gtk_object_class_add_signals (object_class, modulo_rubrica_signals, LAST_SIGNAL);

 klass->applica = NULL;
 klass->aiuto = NULL;
}


static void
modulo_rubrica_marshal_signal (GtkObject *object, GtkSignalFunc func,
			       gpointer func_data, GtkArg *args)
{
  ModuloRubricaSignal rfunc;

  rfunc = (ModuloRubricaSignal) func;
  (*rfunc) (object, GTK_VALUE_INT(args[0]), func_data);
}


static void
modulo_rubrica_init (ModuloRubrica *modulo)
{
  /* bottoni globali al widget */ 
  GList *button_list;

  /* frame */
  GtkWidget *frame_dati;
  GtkWidget *frame_rete;
  GtkWidget *frame_telefono;
  GtkWidget *frame_note;

  /* etichette notebook */
  GtkWidget *label_dati;
  GtkWidget *label_rete;
  GtkWidget *label_telefono;
  GtkWidget *label_note;

  modulo->notebook = gtk_notebook_new();
  
  if (gnome_preferences_get_property_box_apply()) {
    gnome_dialog_append_buttons(GNOME_DIALOG(modulo),
				GNOME_STOCK_BUTTON_OK,
				GNOME_STOCK_BUTTON_APPLY,
				GNOME_STOCK_BUTTON_CLOSE,
				GNOME_STOCK_BUTTON_HELP,
				NULL);
  }
  else {
    gnome_dialog_append_buttons(GNOME_DIALOG(modulo),
				GNOME_STOCK_BUTTON_OK,
				GNOME_STOCK_BUTTON_CANCEL,
			        GNOME_STOCK_BUTTON_HELP,
				NULL);
  }
  
  gnome_dialog_set_default (GNOME_DIALOG(modulo), 0);

  button_list = GNOME_DIALOG(modulo)->buttons;
  
  modulo->ok = GTK_WIDGET(button_list->data);
  button_list = button_list->next;
  
  if (gnome_preferences_get_property_box_apply ()){
    modulo->applica = GTK_WIDGET(button_list->data);
    button_list = button_list->next;
    gtk_widget_set_sensitive (modulo->applica, FALSE);
  } else
    modulo->applica = 0;
  
  modulo->cancella = GTK_WIDGET(button_list->data);
  
  button_list = button_list->next;
  modulo->aiuto = GTK_WIDGET(button_list->data);
  
  
  gtk_signal_connect ( GTK_OBJECT(modulo), "clicked",
		       GTK_SIGNAL_FUNC(dialog_clicked_cb),
		       NULL );
  
  gtk_box_pack_start (GTK_BOX(GNOME_DIALOG(modulo)->vbox),
		      modulo->notebook,
		      TRUE, TRUE, 0);

  frame_dati = modulo_rubrica_crea_pagina_dati(modulo);
  frame_rete = modulo_rubrica_crea_pagina_rete(modulo);
  frame_telefono = modulo_rubrica_crea_pagina_telefono(modulo);
  frame_note = modulo_rubrica_crea_pagina_note(modulo);

  label_dati = gtk_label_new("Dati");
  label_rete = gtk_label_new("Rete");
  label_telefono = gtk_label_new("Telefono");
  label_note = gtk_label_new("Note");

  gtk_widget_show(label_dati);
  gtk_widget_show(label_rete);
  gtk_widget_show(label_telefono);
  gtk_widget_show(label_note);
  
  gtk_notebook_append_page(GTK_NOTEBOOK(modulo->notebook), frame_dati, label_dati);
  gtk_notebook_append_page(GTK_NOTEBOOK(modulo->notebook), frame_rete, label_rete);
  gtk_notebook_append_page(GTK_NOTEBOOK(modulo->notebook), frame_telefono, 
			   label_telefono);
  gtk_notebook_append_page(GTK_NOTEBOOK(modulo->notebook), frame_note, label_note);

  gtk_notebook_set_page(GTK_NOTEBOOK(modulo->notebook), 0);
  
  gtk_widget_show (modulo->notebook);
}


static void
modulo_rubrica_destroy(GtkObject *object)
{
  ModuloRubrica *modulo;
  
  g_return_if_fail (object != NULL);
  g_return_if_fail (IS_MODULO_RUBRICA(object));

  modulo = MODULO_RUBRICA(object);

  GTK_OBJECT_CLASS(parent_class)->destroy (object);
}


GtkWidget *
modulo_rubrica_new(void)
{
  return gtk_type_new(modulo_rubrica_get_type());
}


static void
dialog_clicked_cb(GnomeDialog * dialog, gint button, gpointer data)
{
  ModuloRubrica *mod;
  GtkWidget *page;
  GList *list;
  gboolean dirty = FALSE;
  
  g_return_if_fail(dialog != NULL);
  g_return_if_fail(IS_MODULO_RUBRICA(dialog));
  
  mod = MODULO_RUBRICA (dialog);
  
  if (GTK_NOTEBOOK (mod->notebook)->cur_page != NULL) {
    
    for (list = GTK_NOTEBOOK(mod->notebook)->children;
	 list != NULL;
	 list = list->next) {
      GtkNotebookPage *page = list->data;
      g_assert (page != NULL);
      
      dirty = GPOINTER_TO_INT (gtk_object_get_data(GTK_OBJECT(page->child),
						   MODULO_MODIFICATO));
      
      if (dirty)
	break;
    }
  } else {
    page = NULL;
    dirty = FALSE;
  }
  
  /* Choose which style we did */
  if (mod->applica){
    switch(button) {
    case 0:
      if (dirty)
	applica_e_chiudi (MODULO_RUBRICA (dialog));
      else
	chiudi (MODULO_RUBRICA (dialog));
      break;
    case 1:
      applica (MODULO_RUBRICA (dialog));
      break;
    case 2:
      chiudi (MODULO_RUBRICA (dialog));
      break;
    case 3:
      aiuto (MODULO_RUBRICA (dialog));
      break;
    default:
      g_assert_not_reached();
    }
  } else {
    switch(button) {
    case 0:
      if (dirty)
	applica_e_chiudi (MODULO_RUBRICA (dialog));
      else
	chiudi (MODULO_RUBRICA (dialog));
      break;
    case 1:
      chiudi (MODULO_RUBRICA (dialog));
      break;
    case 2:
      aiuto (MODULO_RUBRICA (dialog));
      break;
    default:
      g_assert_not_reached();
    }
  }
}



static void
set_sensitive (ModuloRubrica *mod, gint dirty)
{
	if (mod->applica)
		gtk_widget_set_sensitive (mod->applica, dirty);
}




void
modulo_rubrica_changed (ModuloRubrica *mod)
{
	GtkWidget *page;

	g_return_if_fail (mod != NULL);
	g_return_if_fail (IS_MODULO_RUBRICA (mod));
	g_return_if_fail (mod->notebook);
	g_return_if_fail (GTK_NOTEBOOK (mod->notebook)->cur_page);
	
	page = GTK_NOTEBOOK (mod->notebook)->cur_page->child;
	g_assert (page != NULL);
	
	gtk_object_set_data(GTK_OBJECT(page),
			    MODULO_MODIFICATO,
			    GINT_TO_POINTER(1));

	set_sensitive (mod, 1);
}



void
modulo_rubrica_set_modified (ModuloRubrica *modulo, gboolean state)
{
	GtkWidget *page;

	g_return_if_fail (modulo != NULL);
	g_return_if_fail (IS_MODULO_RUBRICA (modulo));
	g_return_if_fail (modulo->notebook);
	g_return_if_fail (GTK_NOTEBOOK (modulo->notebook)->cur_page);
	
	page = GTK_NOTEBOOK (modulo->notebook)->cur_page->child;
	g_assert (page != NULL);
	
	gtk_object_set_data(GTK_OBJECT(page),
			    MODULO_MODIFICATO,
			    GINT_TO_POINTER(state ? 1 : 0));

	set_sensitive (modulo, state);
}


static void
applica (ModuloRubrica *modulo)
{
	GList *list;
	gint n;

	g_return_if_fail(GTK_NOTEBOOK(modulo->notebook)->children != NULL);
	
	for (list = GTK_NOTEBOOK(modulo->notebook)->children, n=0;
	     list != NULL;
	     list = g_list_next(list), n++) {
		/* FIXME: there should be a way to report an error
		   during Apply.  That way we could prevent closing
		   the window if there were a problem.  */
		GtkNotebookPage *page = list->data;
		if (gtk_object_get_data(GTK_OBJECT(page->child),
					MODULO_MODIFICATO)) {
			gtk_signal_emit (GTK_OBJECT (modulo),
					 modulo_rubrica_signals[APPLY], n);
			gtk_object_set_data(GTK_OBJECT(page->child),
					    MODULO_MODIFICATO,
					    GINT_TO_POINTER(0));
		}
	}

	/* Emit an apply signal with a button of -1.  This means we
	   just finished a global apply.  Is this a hack?  */
	gtk_signal_emit (GTK_OBJECT (modulo),
			 modulo_rubrica_signals[APPLY], (gint) -1);

	/* Doesn't matter which item we use. */
	set_sensitive (modulo, 0);
}

static void
aiuto (ModuloRubrica *modulo)
{
	gint page;

	page =
	  gtk_notebook_get_current_page (GTK_NOTEBOOK (modulo->notebook));
	gtk_signal_emit (GTK_OBJECT (modulo), modulo_rubrica_signals[HELP],page);
}

static void
chiudi (ModuloRubrica *modulo)
{
  gnome_dialog_close(GNOME_DIALOG(modulo));
}

static void
applica_e_chiudi (ModuloRubrica *modulo)
{
  applica (modulo);
  chiudi (modulo);
}
